[PATCH 03/13] usb: host: ehci: use new USB_RESUME_TIMEOUT

2015-02-13 Thread Felipe Balbi
Make sure we're using the new macro, so our
resume signaling will always pass certification.

Signed-off-by: Felipe Balbi ba...@ti.com
---
 drivers/usb/host/ehci-hub.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/drivers/usb/host/ehci-hub.c b/drivers/usb/host/ehci-hub.c
index 118edb7bdca2..11e487b6fac4 100644
--- a/drivers/usb/host/ehci-hub.c
+++ b/drivers/usb/host/ehci-hub.c
@@ -942,7 +942,7 @@ int ehci_hub_control(
temp = ~PORT_WAKE_BITS;
ehci_writel(ehci, temp | PORT_RESUME, status_reg);
ehci-reset_done[wIndex] = jiffies
-   + msecs_to_jiffies(20);
+   + msecs_to_jiffies(USB_RESUME_TIMEOUT);
set_bit(wIndex, ehci-resuming_ports);
usb_hcd_start_port_resume(hcd-self, wIndex);
break;
diff --git a/drivers/usb/host/ehci-hub.c b/drivers/usb/host/ehci-hub.c
index 87cf86f38b36..b303a4b978f1 100644
--- a/drivers/usb/host/ehci-hub.c
+++ b/drivers/usb/host/ehci-hub.c
@@ -942,7 +942,7 @@ int ehci_hub_control(
temp = ~PORT_WAKE_BITS;
ehci_writel(ehci, temp | PORT_RESUME, status_reg);
ehci-reset_done[wIndex] = jiffies
-   + msecs_to_jiffies(20);
+   + msecs_to_jiffies(USB_RESUME_TIMEOUT);
set_bit(wIndex, ehci-resuming_ports);
usb_hcd_start_port_resume(hcd-self, wIndex);
break;

-- 
2.3.0

--
To unsubscribe from this list: send the line unsubscribe linux-usb in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [PATCH 03/13] usb: host: ehci: use new USB_RESUME_TIMEOUT

2015-02-13 Thread Alan Stern
On Fri, 13 Feb 2015, Felipe Balbi wrote:

 Make sure we're using the new macro, so our
 resume signaling will always pass certification.
 
 Signed-off-by: Felipe Balbi ba...@ti.com
 ---
  drivers/usb/host/ehci-hub.c | 2 +-
  1 file changed, 1 insertion(+), 1 deletion(-)
 
 diff --git a/drivers/usb/host/ehci-hub.c b/drivers/usb/host/ehci-hub.c
 index 118edb7bdca2..11e487b6fac4 100644
 --- a/drivers/usb/host/ehci-hub.c
 +++ b/drivers/usb/host/ehci-hub.c
 @@ -942,7 +942,7 @@ int ehci_hub_control(
   temp = ~PORT_WAKE_BITS;
   ehci_writel(ehci, temp | PORT_RESUME, status_reg);
   ehci-reset_done[wIndex] = jiffies
 - + msecs_to_jiffies(20);
 + + msecs_to_jiffies(USB_RESUME_TIMEOUT);
   set_bit(wIndex, ehci-resuming_ports);
   usb_hcd_start_port_resume(hcd-self, wIndex);
   break;

You missed a second occurrence in ehci_irq(), just following a comment 
that says:

/* start 20 msec resume signaling from this port,
 * and make hub_wq collect PORT_STAT_C_SUSPEND to
 * stop that signaling.  Use 5 ms extra for safety,
 * like usb_port_resume() does.
 */
 
Alan Stern

--
To unsubscribe from this list: send the line unsubscribe linux-usb in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [PATCH 03/13] usb: host: ehci: use new USB_RESUME_TIMEOUT

2015-02-13 Thread Felipe Balbi
On Fri, Feb 13, 2015 at 04:25:53PM -0500, Alan Stern wrote:
 On Fri, 13 Feb 2015, Felipe Balbi wrote:
 
  Make sure we're using the new macro, so our
  resume signaling will always pass certification.
  
  Signed-off-by: Felipe Balbi ba...@ti.com
  ---
   drivers/usb/host/ehci-hub.c | 2 +-
   1 file changed, 1 insertion(+), 1 deletion(-)
  
  diff --git a/drivers/usb/host/ehci-hub.c b/drivers/usb/host/ehci-hub.c
  index 118edb7bdca2..11e487b6fac4 100644
  --- a/drivers/usb/host/ehci-hub.c
  +++ b/drivers/usb/host/ehci-hub.c
  @@ -942,7 +942,7 @@ int ehci_hub_control(
  temp = ~PORT_WAKE_BITS;
  ehci_writel(ehci, temp | PORT_RESUME, status_reg);
  ehci-reset_done[wIndex] = jiffies
  -   + msecs_to_jiffies(20);
  +   + msecs_to_jiffies(USB_RESUME_TIMEOUT);
  set_bit(wIndex, ehci-resuming_ports);
  usb_hcd_start_port_resume(hcd-self, wIndex);
  break;
 
 You missed a second occurrence in ehci_irq(), just following a comment 
 that says:
 
   /* start 20 msec resume signaling from this port,
* and make hub_wq collect PORT_STAT_C_SUSPEND to
* stop that signaling.  Use 5 ms extra for safety,
* like usb_port_resume() does.
*/

fixed:

commit 4639c95ca9d62b3146ef6809687f2a962e167771
Author: Felipe Balbi ba...@ti.com
Date:   Fri Feb 13 14:42:25 2015 -0600

usb: host: ehci: use new USB_RESUME_TIMEOUT

Make sure we're using the new macro, so our
resume signaling will always pass certification.

Signed-off-by: Felipe Balbi ba...@ti.com

diff --git a/drivers/usb/host/ehci-hcd.c b/drivers/usb/host/ehci-hcd.c
index 85e56d1abd23..f4d88dfb26a7 100644
--- a/drivers/usb/host/ehci-hcd.c
+++ b/drivers/usb/host/ehci-hcd.c
@@ -792,12 +792,12 @@ static irqreturn_t ehci_irq (struct usb_hcd *hcd)
ehci-reset_done[i] == 0))
continue;
 
    /* start 20 msec resume signaling from this port,
 * and make hub_wq collect PORT_STAT_C_SUSPEND to
 * stop that signaling.  Use 5 ms extra for safety,
 * like usb_port_resume() does.
 */
-   ehci-reset_done[i] = jiffies + msecs_to_jiffies(25);
+   ehci-reset_done[i] = jiffies +
+   msecs_to_jiffies(USB_RESUME_TIMEOUT);
@@ -792,12 +792,12 @@ static irqreturn_t ehci_irq (struct usb_hcd *hcd)
continue;
 
-   /* start 20 msec resume signaling from this port,
-* and make hub_wq collect PORT_STAT_C_SUSPEND to
-* stop that signaling.  Use 5 ms extra for safety,
-* like usb_port_resume() does.
+   /* start USB_RESUME_TIMEOUT msec resume signaling from
+* this port, and make hub_wq collect
+* PORT_STAT_C_SUSPEND to stop that signaling.
 */
set_bit(i, ehci-resuming_ports);
ehci_dbg (ehci, port %d remote wakeup\n, i + 1);
usb_hcd_start_port_resume(hcd-self, i);
-- 
balbi


signature.asc
Description: Digital signature


Re: [PATCH 03/13] usb: host: ehci: use new USB_RESUME_TIMEOUT

2015-02-13 Thread Alan Stern
On Fri, 13 Feb 2015, Alan Stern wrote:

 On Fri, 13 Feb 2015, Felipe Balbi wrote:
 
  Make sure we're using the new macro, so our
  resume signaling will always pass certification.
  
  Signed-off-by: Felipe Balbi ba...@ti.com
  ---
   drivers/usb/host/ehci-hub.c | 2 +-
   1 file changed, 1 insertion(+), 1 deletion(-)
  
  diff --git a/drivers/usb/host/ehci-hub.c b/drivers/usb/host/ehci-hub.c
  index 118edb7bdca2..11e487b6fac4 100644
  --- a/drivers/usb/host/ehci-hub.c
  +++ b/drivers/usb/host/ehci-hub.c
  @@ -942,7 +942,7 @@ int ehci_hub_control(
  temp = ~PORT_WAKE_BITS;
  ehci_writel(ehci, temp | PORT_RESUME, status_reg);
  ehci-reset_done[wIndex] = jiffies
  -   + msecs_to_jiffies(20);
  +   + msecs_to_jiffies(USB_RESUME_TIMEOUT);
  set_bit(wIndex, ehci-resuming_ports);
  usb_hcd_start_port_resume(hcd-self, wIndex);
  break;
 
 You missed a second occurrence in ehci_irq(), just following a comment 
 that says:
 
   /* start 20 msec resume signaling from this port,
* and make hub_wq collect PORT_STAT_C_SUSPEND to
* stop that signaling.  Use 5 ms extra for safety,
* like usb_port_resume() does.
*/

There's a third occurrence as well, in ehci_bus_resume():

/* msleep for 20ms only if code is trying to resume port */
if (resume_needed) {
spin_unlock_irq(ehci-lock);
msleep(20);
spin_lock_irq(ehci-lock);
if (ehci-shutdown)
goto shutdown;
}

Alan Stern

--
To unsubscribe from this list: send the line unsubscribe linux-usb in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [PATCH 03/13] usb: host: ehci: use new USB_RESUME_TIMEOUT

2015-02-13 Thread Felipe Balbi
On Fri, Feb 13, 2015 at 04:40:09PM -0500, Alan Stern wrote:
 On Fri, 13 Feb 2015, Alan Stern wrote:
 
  On Fri, 13 Feb 2015, Felipe Balbi wrote:
  
   Make sure we're using the new macro, so our
   resume signaling will always pass certification.
   
   Signed-off-by: Felipe Balbi ba...@ti.com
   ---
drivers/usb/host/ehci-hub.c | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
   
   diff --git a/drivers/usb/host/ehci-hub.c b/drivers/usb/host/ehci-hub.c
   index 118edb7bdca2..11e487b6fac4 100644
   --- a/drivers/usb/host/ehci-hub.c
   +++ b/drivers/usb/host/ehci-hub.c
   @@ -942,7 +942,7 @@ int ehci_hub_control(
 temp = ~PORT_WAKE_BITS;
 ehci_writel(ehci, temp | PORT_RESUME, status_reg);
 ehci-reset_done[wIndex] = jiffies
   - + msecs_to_jiffies(20);
   + + msecs_to_jiffies(USB_RESUME_TIMEOUT);
 set_bit(wIndex, ehci-resuming_ports);
 usb_hcd_start_port_resume(hcd-self, wIndex);
 break;
  
  You missed a second occurrence in ehci_irq(), just following a comment 
  that says:
  
  /* start 20 msec resume signaling from this port,
   * and make hub_wq collect PORT_STAT_C_SUSPEND to
   * stop that signaling.  Use 5 ms extra for safety,
   * like usb_port_resume() does.
   */
 
 There's a third occurrence as well, in ehci_bus_resume():
 
   /* msleep for 20ms only if code is trying to resume port */
   if (resume_needed) {
   spin_unlock_irq(ehci-lock);
   msleep(20);
   spin_lock_irq(ehci-lock);
   if (ehci-shutdown)
   goto shutdown;
   }

fixed this one too, thanks :-)

-- 
balbi


signature.asc
Description: Digital signature